class Number:
	def add_numbers(num1,num2):
		return num1 + num2

	def subtact_numbers(num1,num2):
		return num1 - num2

	def multy_numbers(num1,num2):
		return num1 * num2

	def divide_numbers(num1,num2):
		return num1 / num2




# -*- coding: utf-8 -*-

"""
simplecalculator library
-------------------------

This is a proof of concept of a simple calculator library, written in Python.

It mimick the behavior of a very simple desktop calculator. You give it a list
of numbers and operations as a string and it will create a trace of the
operations performed.  That trace is stores in BasicCalculator.log. The most
recent state of the LCD display is stored in Basic Calculator
"""

__title__ = 'calculator'
__version__ = '0.0.7'
__build__ = 0x000003
__author__ = 'kuldeep khatana'
__license__ = 'The MIT License'
__copyright__ = 'Copyright 2020 kuldeep khatana'

from . import calc


from setuptools import setup, find_packages
import os

long_description  = "sample-python-package"
long_description += "This is a basic Python module and you can simply add this by using this command."
long_description += "pip install kcalculator or pip3 install kcalculator"

long_description += "Note:-"
long_description += "It basicly perform on addition, subtraction, multiply or divide operations."
long_description += "for Now it perform only basic operation."
long_description += "Ex: - a +b 2+3 = 5"
long_description + "How to use this package"
long_description + "from calc import calc"
long_description + "print(calc.add_numberes(4,5))"
long_description + "This package works for only add_numbers, subtact_numbers, multy_numbers, divide_numbers"

# BASE_DIR = os.path.dirname(os.path.realpath(__file__))

# with open(BASE_DIR+"/README.md", "r") as fh:
#     long_description = fh.read()
classification = [
	'Development status :: 5 - Production/stable',
	'Intended Audience :: Education',
	'Operating System :: Linux :: ubuntu',
	'License :: OSI Approved :: MIT License',
	'Programming Language :: PYthon :: 3'
]

setup(
	name='kcalculator',
	version='0.0.8',
	description='A baisc calulcator',
	long_description=long_description,
	long_description_content_type="text/markdown",
	url='https://github.com/softprodigyofficial/sample-python-package.git',
	author='kuldeep khatana',
	author_email='kuldeep.si.softprodigy@gmail.com',
	License='MIT',
	classifiers=[
		"Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
	],
	keywords='calulcator',
	package=find_packages(),
	install_requires=[''],
	py_modules=['calc.calc'],
)

